declare("ACM", ACM or {})
--[[
This is the Actions Command Menu - a form of extensible macro system for Vendetta Online that goes directly on the HUD. By using a series of commands, preferably bound to the arrow keys, a pilot can navigate a menu-ish interface for giving quick commands on a battlefield or execute a set of aliases, hopefully without the need to exit combat. 

to future luxen, https://www.vendetta-online.com/x/msgboard/16/25912

 - Luxen De'Mark, 2020
]]--

ACM.Expected = "dv2"
ACM.Version = gkini.ReadString("ACM", "Version", "null")
ACM.ResetTimer = Timer()
ACM.ActionCountdownTimer = Timer()
ACM.ActionCountdownCounter = 5
ACM.ComList = {}
ACM.OutputLoc = gkini.ReadString("ACM", "OutputLoc", "say_group")
if ACM.Version ~= ACM.Expected then
	ACM.ComList = {
		[0] = 'ACM Module',
		[1] = {
			[0] = "Configure",
			['Action'] = "/ACMConfig",
		},
		[2] = {
			[0] = "Comms...",
			[1] = {
				[0] = "SOS",
				['Action'] = "'I need assistance!'",
			},
			[2] = {
				[0] = "Attack",
				['Action'] = "/ACMcustom attack",
			},
			[3] = {
				[0] = "Responses...",
				[1] = {
					[0] = "Affirmative!",
					['Action'] = "'Affirmative!'",
				},
				[2] = {
					[0] = "Reloading!",
					['Action'] = "'Reloading!'",
				},
				[3] = {
					[0] = "Negative!",
					['Action'] = "'Negative!'",
				},
				[4] = {
					[0] = "Timing",
					['Action'] = "/ACMcustom count",
				},
			},
			[4] = {
				[0] = "Formation",
				['Action'] = "'Follow me in formation!'",
			},
		},
		[3] = {
			[0] = "Custom Menu...",
			[1] = {
				[0] = "Pay target",
				['Action'] = "/givemoney %target% 300000",
			},
			[2] = {
				[0] = "Greet",
				['Action'] = "Greetings!",
			},
			[3] = {
				[0] = "Mark enemy status",
				['Action'] = "/designateenemy",
			},
			[4] = {
				[0] = "Clear enemy status",
				['Action'] = "/cleardesignateenemy",
			},
		},
		[4] = {
			[0] = "Hide ACM",
			['Action'] = "/ACMcustom hide",
		},
	}
	gkini.WriteString("ACM", "Version", ACM.Expected)
	gkini.WriteString("ACM", "ComList", spickle(ACM.ComList))
	gkini.WriteString("ACM", "OutputLoc", ACM.OutputLoc)
else
	ACM.ComList = unspickle(gkini.ReadString("ACM", "ComList", "{[0] = 'Error!', ['Action'] = 'say ERROR!',}"))
end

ACM.CurrentList = {
	['state'] = ACM.ComList,
	['name'] = "ACM Module",
	[1] = "",
	[2] = "",
	[3] = "",
	[4] = "",
}

ACM.Display = iup.vbox {
	
	iup.label {
		title = "ACM:",
		font = Font.H6,
	},
	iup.label {
		title = "",
		font = Font.H6,
	},
	iup.label {
		title = "",
		font = Font.H6,
	},
	iup.label {
		title = "",
		font = Font.H6,
	},
	iup.label {
		title = "",
		font = Font.H6,
	},
	
}

ACM.DisplayFrame = iup.frame {
	ACM.Display,
	cx = -10,
	cy = 600,
}

function ACM.CreateHUDLayer()
	iup.Append(iup.GetNextChild(HUD.cboxlayer), ACM.DisplayFrame)
	ACM.DisplayFrame:map()
end

RegisterEvent(ACM.CreateHUDLayer, "HUD_SHOW")
--RegisterEvent("PLUGINS_LOADED", ACM.CreateHUDLayer)

function ACM.UpdateHUDLayer()
	
	ACM.Display[1].title = ACM.CurrentList['name']
	ACM.Display[2].title = "1: " .. ACM.CurrentList[1]
	ACM.Display[3].title = "2: " .. ACM.CurrentList[2]
	ACM.Display[4].title = "3: " .. ACM.CurrentList[3]
	ACM.Display[5].title = "4: " .. ACM.CurrentList[4]
	iup.Refresh(ACM.Display)
	
end

function ACM.UpdateDisplayList(direction)
	
	ACM.DisplayFrame.visible = "YES"
	if ACM.CurrentList['state'][direction]['Action'] == nil then
		if ACM.CurrentList['state'][direction][1] == nil then
			ACM.ResetDisplayList()
		else
			ACM.CurrentList[1] = ACM.CurrentList['state'][direction][1][0] or ""
			ACM.CurrentList[2] = ACM.CurrentList['state'][direction][2][0] or ""
			ACM.CurrentList[3] = ACM.CurrentList['state'][direction][3][0] or ""
			ACM.CurrentList[4] = ACM.CurrentList['state'][direction][4][0] or ""
			ACM.CurrentList["name"] = ACM.CurrentList['state'][direction][0] or "ACM:"
			ACM.CurrentList['state'] = ACM.CurrentList['state'][direction]
			
			ACM.UpdateHUDLayer()
		end
	else
		if string.sub(ACM.CurrentList['state'][direction]['Action'], 1, 1) == "/" then
			gkinterface.GKProcessCommand(string.sub(ACM.CurrentList['state'][direction]['Action'], 2, -1))
		else
			gkinterface.GKProcessCommand(ACM.OutputLoc .. " " .. ACM.CurrentList['state'][direction]['Action'])
		end
		ACM.ResetDisplayList()
	end
	
	ACM.ResetTimer:SetTimeout(25000, function() ACM.ResetDisplayList() end)
	
end

function ACM.ResetDisplayList()
	
	ACM.CurrentList['state'] = ACM.ComList
	ACM.CurrentList['name'] = ACM.ComList[0]
	ACM.CurrentList[1] = ACM.ComList[1][0] or ""
	ACM.CurrentList[2] = ACM.ComList[2][0] or ""
	ACM.CurrentList[3] = ACM.ComList[3][0] or ""
	ACM.CurrentList[4] = ACM.ComList[4][0] or ""
	ACM.UpdateHUDLayer()
	
end

ACM.ResetDisplayList()

function ACM.Input1()
	ACM.UpdateDisplayList(1)
end

function ACM.Input2()
	ACM.UpdateDisplayList(2)
end

function ACM.Input3()
	ACM.UpdateDisplayList(3)
end

function ACM.Input4()
	ACM.UpdateDisplayList(4)
end

RegisterUserCommand("ACM1", ACM.Input1)
RegisterUserCommand("ACM2", ACM.Input2)
RegisterUserCommand("ACM3", ACM.Input3)
RegisterUserCommand("ACM4", ACM.Input4)

dofile("ACMdialog.lua")












